.. image:: https://badge.fury.io/py/pymediaroom.svg
    :target: https://badge.fury.io/py/pymediaroom
    
pymediaroom - Python Remote Control for Mediaroom STB
=====================================================

Mediaroom is an IPTV platform currently developed by Ericsson with deployments worldwide,
for more information check `wikipedia`_.

This python package provides an api that sends to the set-up-box the same commands the IR remote sends.
You do not require any special hardware, you just need to run this package from an equipment connected 
to the same network segment as the set-up-box.

.. _wikipedia: https://en.wikipedia.org/wiki/Ericsson_Mediaroom


Available Keys
==============

- Number0
- Number1
- Number2
- Number3
- Number4
- Number5
- Number6
- Number7
- Number8
- Number9
- Back
- OK
- Menu
- Left
- Right
- Up
- Down
- ProgUp
- ProgDown
- VolUp
- VolDown
- Mute
- Exit
- Guide
- Switch
- Rec
- PlayPause
- Forward
- Rewind
- Power
- Info
- Search
- Enter
- VoD
- Stop
- Red
- Green
- Yellow
- Blue
- Delete
- Options
- Open
- AV
- Prev
- Next
- OptionsAlt
- Favourite

Copyright
---------

pymediaroom is Copyright (C) 2017 Diogo Gomes <diogogomes@gmail.com> 
